summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/object_factory.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit9150603ad32928e9c514c0492a8518b742d82ac3 (patch)
tree6e3f83e2b94146bb42eed57eb6dd8f2fb0369e6f /umbrello/umbrello/object_factory.h
parent6b126a99d5eecef5cb96589ed5c2e522bcb06ca9 (diff)
downloadtdesdk-9150603ad32928e9c514c0492a8518b742d82ac3.tar.gz
tdesdk-9150603ad32928e9c514c0492a8518b742d82ac3.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/object_factory.h')
-rw-r--r--umbrello/umbrello/object_factory.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/object_factory.h b/umbrello/umbrello/object_factory.h
index 541975c0..69338203 100644
--- a/umbrello/umbrello/object_factory.h
+++ b/umbrello/umbrello/object_factory.h
@@ -31,7 +31,7 @@ namespace Object_Factory {
* @param n A name to give to the object (optional.)
* If not given then an input dialog prompts
* the user to supply a name.
* @param tqparentPkg The object's tqparent package.
* @param solicitNewName Ask user for a different name if an object
* of the given name already exists.
* If set to false and the name already exists
@@ -40,7 +40,7 @@ namespace Object_Factory {
*/
UMLObject* createUMLObject(Uml::Object_Type type,
const TQString &n = TQString(),
- UMLPackage *tqparentPkg = 0,
+ UMLPackage *parentPkg = 0,
bool solicitNewName = true);
/**
@@ -31,7 +31,7 @@ namespace Object_Factory {
* If not given then an input dialog prompts
* the user to supply a name.
- * @param tqparentPkg The object's tqparent package.
+ * @param parentPkg The object's tqparent package.
* @param solicitNewName Ask user for a different name if an object
* of the given name already exists.